import {
  select,
  csv,
  scaleLinear,
  scalePoint,
  scaleOrdinal,
  schemeCategory10,
  extent,
  line,
  brushY,
} from 'd3';
import { observeResize } from '@curran/responsive-axes';

import { parallelCoordinates } from './parallelCoordinates';

const gistUrl = 'https://gist.githubusercontent.com/KangjianWu/db06675bba6753a66a7dcb861d37dbf7/raw/d3e4b472fbac3fb6d588e190d76c400b927a36cf/Covid_worldWide.csv'; // 使用您提供的URL

export const main = (container, { state, setState }) => {
  csv(gistUrl).then(data => {
    data.forEach((d, i) => {
  d.id = d['Serial Number']; 
  
  ['Total Cases', 'Total Deaths', 'Total Recovered', 'Active Cases', 'Total Test', 'Population'].forEach(field => {
    d[field] = d[field] === 'N/A' ? 0 : +d[field].replace(/,/g, '');
    if (isNaN(d[field])) {
      console.error(`Conversion error for ${field} at row ${i}`, d);
      d[field] = 0;
    }
  });
});

    const columns = [
      'Total Cases',
      'Total Deaths',
      'Total Recovered',
      'Active Cases',
      'Total Test',
      'Population',
    ];

    const columnTypes = {
      'Total Cases': 'quantitative',
      'Total Deaths': 'quantitative',
      'Total Recovered': 'quantitative',
      'Active Cases': 'quantitative',
      'Total Test': 'quantitative',
      'Population': 'quantitative',
    };

    const colorValue = (d) => d['Total Deaths'];
    const idValue = (d) => d.id;

    const dimensions = observeResize({
      state,
      setState,
      container,
    });

    if (dimensions === null) return;
    const { width, height } = dimensions;

    if (!state.brushedIntervals) {
      setState((state) => ({
        ...state,
        brushedIntervals: {},
      }));
      return;
    }
    const { brushedIntervals } = state;

    const updateBrushedInterval = ({ column, interval }) => {
      setState((state) => ({
        ...state,
        brushedIntervals: {
          ...state.brushedIntervals,
          [column]: interval,
        },
      }));
    };

    const svg = select(container)
      .selectAll('svg')
      .data([null])
      .join('svg')
      .attr('width', width)
      .attr('height', height)
      .style('background', '#164599');

    svg.call(parallelCoordinates, {
      data,
      columns,
      columnTypes,
      colorValue,
      idValue,
      width,
      height,
      brushedIntervals,
      updateBrushedInterval,
   